<?php

switch ($messaggio) {

case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case "Nuovo messaggio a":  			$messaggio = "Nytt meddelande till"; break;
case "da mostrare dopo le":  			$messaggio = "ska visas efter"; break;
case "il":  					$messaggio = "det"; break;
case "testo del messaggio":  			$messaggio = "meddelandetext"; break;
case "Messaggi":  				$messaggio = "Meddelanden"; break;
case "Spedisci":  				$messaggio = "S&auml;nd"; break;
case "Messaggio inviato":  			$messaggio = "Meddelande s&auml;nt"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "N°":  					$messaggio = "nr"; break;
case "Mittente":  				$messaggio = "Avs&auml;ndare"; break;
case "Data":  					$messaggio = "Datum"; break;
case "Azioni":  				$messaggio = "&Aring;tg&auml;rder"; break;
case "Elimina":  				$messaggio = "Ta bort"; break;
case "Messaggio eliminato":  			$messaggio = "Meddelande borttaget"; break;
case "tutti":  					$messaggio = "alla"; break;
case "SI":  					$messaggio = "JA"; break;
case "Si è sicuri di voler eliminare la richiesta di prenotazione di":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill ta bort bokningsf&ouml;rfr&aring;gan fr&aring;n"; break;
case "non ancora inserita?":  			$messaggio = "inte &auml;n infogad?"; break;
case "Inserisci la prenotazione":  		$messaggio = "Infoga bokningen"; break;
case "Visualizza il documento":  		$messaggio = "Se dokument"; break;
case "di tipo":  				$messaggio = "typ"; break;
case "Inserito":  				$messaggio = "Infogad"; break;
case "Elimina tutti i messaggi":  		$messaggio = "Ta bort alla meddelanden"; break;
case "Si è sicuri di voler eliminare <div style=\"display: inline; color: red;\"><b>tutti i messaggi</b></div>":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill ta bort <div style=\"display: inline; color: red;\"><b>alla meddelanden</b></div>"; break;
case "Messaggi eliminati":  			$messaggio = "Meddelanden borttagna"; break;
case "arrivati":  				$messaggio = "anl&auml;nt"; break;
case "prima del":  				$messaggio = "f&ouml;re"; break;
case "dopo il":  				$messaggio = "efter"; break;
case "Testo":  					$messaggio = "Text"; break;
case "Scarica messaggi email":  		$messaggio = "Download email messages"; break;
case "Nessun nuovo messaggio":  		$messaggio = "No new message"; break;
case "Nuovi messaggi":  			$messaggio = "New messages"; break;
case "Scaricati":  				$messaggio = "Downloaded"; break;
case "Connessione al server":  			$messaggio = "The connection to server"; break;
case "non riuscita!":  				$messaggio = "was refused!"; break;
case "Controllare i dati immessi in":  		$messaggio = "Check data inserted in"; break;
case "configura e personalizza":  		$messaggio = "configure and customize"; break;
case "Dati ricavati dal messaggio email":  	$messaggio = "Data extracted from email message"; break;
case "Controlla disponibilità":  		$messaggio = "Check availability"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Email":  					$messaggio = "Email"; break;
case "arrivo":  				$messaggio = "arrival"; break;
case "partenza":  				$messaggio = "departure"; break;
case "notti":  					$messaggio = "nights"; break;
case "persone":  				$messaggio = "people"; break;
case "individui":  				$messaggio = "persons"; break;
case "ospiti":  				$messaggio = "guests"; break;
case "adulti":  				$messaggio = "adults"; break;
case "bambini":  				$messaggio = "children"; break;
case "gruppo":  				$messaggio = "party"; break;
case "date":  					$messaggio = "dates"; break;
case "viaggiatori":  				$messaggio = "travelers"; break;
case "periodo":  				$messaggio = "period"; break;
case "Per gli account su gmail potrebbe essere necessario abilitare l'opzione":	$messaggio = "For gmail accounts you may have to enable the option"; break;
case "e/o per una volta usare prima la funzione":	$messaggio = "and/or for once use beforehand the function"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>